audioScatter(x, y = NULL, z = NULL, data, purge.plots = FALSE, show.plots = TRUE, bins = 30, aspect = 1, radius = floor(sqrt(bins))-1, key = "C", quality = "Major", tempo = 115, directory = file.path (Sys.getenv("R_LIBS_USER"), "audiolyzR"), output = file.path (tempdir(), "json_matrix"), write.to.home = NULL, ...)
panel.audiolyzR(x, y, ...)xyplot (y ~ x + z, data=data, outer=FALSE)
-or-
The x-axis variable name as a text string.
hexbin() and hexbinplot().
audio*Plot* function, the program will download and install automatically. By default, the app installs into the file.path (Sys.getenv("R_LIBS_USER"), "audiolyzR") directory, which is where the package's functions will look for it. You are free to install it whereever you like, but you must specify its parent directory in your function calls. If you prefer to install it yourself: audiolyzR application for Mac: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_mac_v5.zip audiolyzR application for Windows: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_win_v5.zipoutput directory in order to generate audio.
Also, a plot will be produced in the graphics window.panel.audiolyzR adds an audio plot component to xyplot(). This functions at a basic level of implementation and only currently supports outer = FALSE plots. Support for more complex lattice graphics will be incorporated into future releases.
hexbin
##Basic audioScatter example
## Not run:
# data(NHANES)
# audioScatter("Weight","BMI",data=NHANES)
# audioScatter(BMI ~ Weight + Transferin,data=NHANES)
# ## End(Not run)
Run the code above in your browser using DataLab