hexplom. The audiolyzR plots are played according to the selected plot in the drop-down menu.
The result can be considered similar to "movements" of a piece of music, with each scatterplot representing a separate movement within the larger piece.
audioSplom(x = NULL, data, purge.plots = FALSE, bins = 30, aspect = 1, radius = floor (sqrt(bins)) - 1, key = "C", quality = "Major", tempo = 115, directory = file.path (Sys.getenv("R_LIBS_USER"), "audiolyzR"), output = file.path (tempdir(), "json_matrix"), write.to.home = NULL, ...)hexbin() and hexbinplot().
audio*Plot* function, the program will download and install automatically. By default, the app installs into the file.path (Sys.getenv("R_LIBS_USER"), "audiolyzR") directory, which is where the package's functions will look for it. You are free to install it whereever you like, but you must specify its parent directory in your function calls. If you prefer to install it yourself: audiolyzR application for Mac: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_mac_v5.zip audiolyzR application for Windows: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_win_v5.zipoutput directory in order to generate audio.
Also, a plot will be produced in the graphics window.hexbin
##Simple audioSplom example
## Not run:
# data(NHANES)
# audioSplom(data=NHANES)
# ## End(Not run)
Run the code above in your browser using DataLab