| Package: |
| audiolyzR |
| Type: |
| Package |
| Version: |
| 0.4-9 |
| Date: |
| 2013-2-16 |
| License: |
| GPL-2 |
Things to note and pay attention to while you listen: 1) The X or horizontal axis corresponds to time (not pitch). 2) Pitch corresponds to the Y or vertical axis. 3) Reverb is inversely proportional to correlation (more reverb for less correlation). 4) Synthesizer dryness is mildly related to number of points in a column. 5) Relative note volume is inversely proportional to the number of notes in a neighborhood of each (higher volume for fewer neighbors)
Instructions for the external audiolyzR application: In order to run audiolyzR, you need to install the appropriate standalone application. The first time you run any audiolyzR command, it will automatically install the appropriate version for your system. If you prefer to download the files yourself: Mac: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_mac_v5.zip
Windows: http://s3.amazonaws.com/audiolyzR/installers/the_audiolyzR_win_v5.zip
Also, make sure you are running a functioning version of Apple QuickTime, or you won't see the visual representation of the data in the synthesizer.
##Basic audiolyzR examples
data(NHANES)
## Not run:
# ##Scatter Plot
# audioScatter(BMI ~ Weight,data=NHANES)
#
# ##Scatterplot matrix
# audioSplom(data=NHANES, bins=20)
#
# ##Histogram
# audioHist(NHANES$Weight, name="Weight")
# ## End(Not run)
Run the code above in your browser using DataLab